function [modelInfo] = BuildDXDT(InputFile,OutputFile);
%
% Mandatory Input Parameters:
%   InputFile              -   BCL file
%   OutputFile             -   .m file to write the dXdT to
%
% Output Parameters
%
% Structure modelInfo, containing the following fields:
%   SVarList               -   A list of state variable names
%   ParList                -   A list of parameter names
%   SVarID                 -   A list of identifying names for the state
%                              variables
%   ParID                  -   A list of identifying names for the free
%                              parameters
%
% It also constructs a .mat file with the modelInfo structure in it
% so recompilation is not always necessary, and supplying it with distributed
% clusters is easy. And last but not least, a .log file is generated which
% shows all the calculations involved in the Gibbs energy change of the reactions
% and pKa's. Both ionic strength and temperature corrections are listed in
% the log file.
%

% Version 2.0 

% function [modelInfo] = BuildDXDT(InputFile,OutputFile)
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

%% Thermodynamic constants
R  = 8.314e-3;

%% Parameter initialization
% ion indices
i_h = 1;
i_m = 2;
i_k = 3;

% names of the different ions with dissociation to other species
label{ i_h } = 'H';
label{ i_m } = 'M';
label{ i_k } = 'K';

% names of the K values (ie Kh Km Kg)
kName{ i_h } = 'h';
kName{ i_m } = 'm';
kName{ i_k } = 'k';

% charges of the individual ions
ionCharge{ i_h } = 1;
ionCharge{ i_m } = 2;
ionCharge{ i_k } = 1;

% main model file keywords
keywords{1} = 'compartment';
keywords{2} = 'transport';
keywords{3} = 'clamped';
keywords{4} = 'EOF';
keywords{5} = 'permeate';

% free parameter counters
Npar = 0;
ipar = 0;

%% Import databases
% Read Reactant Database
vnum = sscanf(version('-release'), '%d %*c');
[nums,strings] = xlsread('ReactantDatabase.xls');
if (vnum < 2012) 
       strings = strings( :, 2:end ); 
end
strings = strings( 2:end, : );
ReactantNames = strings(:,2);       % Grab the reactant abbreviations
dGfo = nums(:,4);                   % Grab the Gibbs energies of formation
dHf = nums(:,5);                    % Grab the enthalpy of formation
chargeList = nums(:,6);             % Grab the species chargse
protonList = nums(:,7);             % Grab the number of protons
pK( i_h, : ) = nums(:,8);           % Grab the pKa for hydrogen
dHrK( i_h, : ) = nums(:,9);         % Reaction enthalpy for H binding
pK( i_m, : ) = nums(:,10);          % Grab the pKa for magnesium
dHrK( i_m, : ) = nums(:,11);        % Reaction enthalpy for Mg binding
pK( i_k, : ) = nums(:,12);          % Grab the pKa for potassium
dHrK( i_k, : ) = nums(:,13);        % Reaction enthalpy for K binding

% Read Reaction Database
[nums,strings] = xlsread('ReactionDatabase.xls');
if (vnum < 2012) 
       strings = strings( :, 2:end ); 
end
ReactionNames = strings(:,1);
ReactionAbbrvs = strings(:,2);
ReactionStoics = strings(:,3);

% Read Transport Database
[nums,strings] = xlsread('TransportDatabase.xls');
if (vnum < 2012) 
       strings = strings( :, 2:end); 
end
TransportNames = strings(:,1);
TransportAbbrvs = strings(:,2);
TransportStoics = strings(:,3);
TransportCurrents = nums(:,5);

%% Reading biochemical script language model 
F = textread(InputFile,'%s');
F_index = 0;

%% Initializing Data for current compartment
Qr = []; % Stoichiometric Matrix
Qt = [];
Qe = [];
FluxEquations = [];         % List of flux equations from the enzyme modules
DGEquations = [];           % List of equations for computing DG's
KeqEquations = [];          % List of equations for computing apparent Keq's
ReactantList  = [];         % The global list of reactants
ReactionList = [];          % List of reactions modeled
QReactions   = [];          % List of compartment-specific reactions
SVarList = [];              % The list of reactant varibles modeled
ParList = [];               % List of unspecified variables (added by Joep)
FluxID = [];                % List of output fluxes (added by Joep)
DGeqString = '';            % Used to produce the log file
KiEq = '';                  % Used to produce the log file
CompList = [];
CompOfReaction = [];
% Volumes = []; %FW: commented by FW. Volumes are identified as water volumes and region volumes
VolumesWater = []; %FW: added by FW. VolumesWater = l region water/l region
VolumesRegion = []; %FW: added by FW. VolumesRegions = l region/l tissue
CompSVindices = [];
clamped_variables = [];
StoM = [];  %FW: added by FW to initialize StoM array to avoid error "Undefined function or variable 'StoM'"
Lm = []; %FW: added by FW to initialize StoM array to avoid error "Undefined function or variable 'StoM'"

fluxesDone = []; % variable used to keep track of fluxes that were already done (permeability)
TransportList = [];
QTransports  = [];
TransportStoich = cell(length(label),1);
TransportComp = cell(length(label),1);
Transports = cell(length(label),1);
shuttleStoich = cell(length(label),1);
shuttleComp = cell(length(label),1);
shuttles = cell(length(label),1); % ions transported along with species
permeabilities = cell(1);
Membranes = [];
GlobalLines = [];

CompIndex = 0;
Nrl = 0; % number of reactants
Nsv = 0; % number of state variables
kr = 0;   % number of reactions
kt = 0;

%% Set 'default' ionic strength and temperature

% Temperature (if none specified in bsl file)
T_new = 298.15;

% Desired ionic strength (if none specified)
I_new = 0.17;

% Temperature at which Gibbs energies and enthalpies of reactants in the
% reactant database were determined.
T_tabulated_reactants = 298.15;

% Temperature at which dissociation constants were determined
T_tabulated_pKa = 298.15;

% Ionic strength for reactants
I_tabulated_reactants = 0;

% Ionic strengths for pKa's
I_tabulated_pKa = .1;

disp( sprintf( '%s', BISENlogo(1) ) );
disp(sprintf('  Input file:\t\t\t\t\t%s', InputFile ) );

%% Process general model variables
% mark the end of the global variables section while looking for ionic
% strength or temperature specification
a = 1;

while( ~strcmp( F{F_index+1}, 'compartment' ) & ~strcmp( F{F_index+1}, 'export' ) )
    F_index = F_index + 1;

    % check if there are ionic strengths specified here
    if strcmp( lower( F{F_index} ), 'ionic_strength' )
        I_new = str2num( F{ F_index + 1 } );
        if ~isnumeric( I_new ) | isempty( I_new )
            error( sprintf( 'Invalid value for ionic strength (value given: %s)!', F{F_index+1} ) );
            return;      
        end
    end
    % check if there is a temperature specified
    if strcmp( lower( F{F_index} ), 'temperature' )
        if strcmp( lower( F{F_index+1} ), 'unspecified' )
            % Unspecified -> use the input and make sure all expressions
            % can be changed dynamically. This has not yet been implemented
            % and remains future work in version v1.0!
            T_new = 0;         
        else
            T_new = str2num( F{ F_index + 1 } );
            if ~isnumeric( T_new ) | isempty( T_new )
                error( sprintf( 'Invalid value for temperature (value given: %s)!', F{F_index+1} ) );
                return;
            else
                % Celcius -> Kelvin
                T_new = T_new + 273.15;
            end
        end
    end
end

% parse unspecified parameters in the globals section and put them in the
% unspecified parameter list
lastToken = '';
if F_index > 0
    % get the lines in one single string (without losing linebreaks or spaces)
    GlobalLines = textread(InputFile,'%s', 'endofline', '`', 'delimiter', '`');
    GlobalLines = regexprep( GlobalLines, '\r', '`\r' );
    GlobalLines = regexprep( GlobalLines, '\n', '`\n' );
    GlobalLines = regexprep( GlobalLines, 'ionic_strength(\w*)', '% $0', 'ignorecase' );
    GlobalLines = regexprep( GlobalLines, 'temperature(\w*)', '% $0', 'ignorecase' );      
    GlobalLines = regexprep( GlobalLines, '`\r`\n', '\r\n' );  
    GlobalLines = GlobalLines{1};
    GlobalLines = GlobalLines( 1 : min( [findstr( GlobalLines, 'compartment' ); findstr( GlobalLines, 'export' )] ) - 1 ); %FW: reserved the strings before reach any of "compartment" or "export"
    
    % start with the whole string and process piecewise
    tmp = GlobalLines;
    tmp2 = '';
    while ( length( tmp ) > 1 )
        % grab a word
        [tok,tmp] = strtok( tmp, '= ;' );
        % if the current word is 'unspecified', then the last
        % word was a variable name!
        if strcmp( tok, 'unspecified' );
            ipar = ipar + 1;
            Npar = Npar + 1;
            % replace the unspecified with the proper id
            GlobalLines = regexprep( GlobalLines, ...
                'unspecified', sprintf('par(%d)',ipar), 'once' );
            % put it in the parameter list
            ParList{length(ParList)+1} = lastToken; %;strtok(tok, ' =' );       
        end
        lastToken = tok;        
    end
    % add linebreaks for readability
    GlobalLines = regexprep( GlobalLines, ';', sprintf(';\r\n') );
end
F_index = F_index + 1;

%% Export section
% Create a list of variables that the user wishes to have exported from
% the model
exportVars = '';
exportVars2 = '';
q=0;
while( ~strcmp( F{F_index}, 'compartment' ) )
    if strcmp( F{F_index}, 'export' )
        q = q + 1;
        if q ~= 1
            exportVars = strcat( exportVars, ', ' );
        end
        exportVars = strcat( exportVars, F{F_index + 1} );
        exportVars2 = sprintf( ...
            '%stry\r\nvarargout(%d) = {%s};\r\ncatch\r\nvarargout(%d) = {0};\r\nend\r\n', ...
            exportVars2, q, F{F_index + 1}, q );
        F_index = F_index + 1;
    end
    F_index = F_index + 1;
end


%% Compute factors needed for ionic strength and temperature correction
if T_new ~= 0
    disp( sprintf( '  Temperature:\t\t\t\t\t%.2f Kelvin', T_new ) );
else
    disp( sprintf( '  Temperature:\t\t\t\t\tunspecified') ); %FW: T_new deleted by FW.
end
disp( sprintf( '  Ionic strength:\t\t\t\t%.2f M', I_new ) );

[ beta_K, beta_G, beta_H, beta_H2 ] = getISCF( T_new, I_tabulated_reactants, I_tabulated_pKa, I_new  );

%% Process compartments
while strcmp(F{F_index},'compartment')
%  if strcmp(F{F_index},'compartment')
    F_index = F_index + 1;
    comp_name = F{F_index};
    disp( sprintf( '\n  Processing compartment:\t\t%s', comp_name ) );
    F_index = F_index + 1;
%     Volumes = [Volumes str2num(F{F_index})]; %FW:commented by FW. water fractions in different compartments, [=] l water/(l comp)
    VolumesWater = [VolumesWater str2num(F{F_index})]; %FW: added by FW. VolumesWater = l region water/l region
    F_index = F_index + 1; %FW: added by FW.
    VolumesRegion = [VolumesRegion str2num(F{F_index})]; %FW: added by FW. VolumesRegion = l region/l tissue
    CompIndex = CompIndex + 1;
    CompSVindices{CompIndex} = [];
    CompList{CompIndex} = comp_name;
    F_index = F_index + 1;

    n_svars_begin = length(SVarList);
    while ~sum(strcmp(keywords,F{F_index}))
  
      Abbrv = F{F_index};
      F_index = F_index + 1;
      ModelName = F{F_index};
      F_index = F_index + 1;
      if ~sum(strcmp(ReactionAbbrvs, Abbrv))
        noabbrv(Abbrv)
      else
        [s,Rxn_i] = max(strcmp( ReactionAbbrvs, Abbrv ));
      end

      kr = kr + 1;
      QReactions{kr} = strcat(Abbrv,'_',comp_name);
      CompOfReaction{kr} = comp_name;

      [Reactants,StoichArray,Equations] = ...
          ReadReactionEntry(Abbrv,ModelName,ReactionStoics(Rxn_i),comp_name);

      %% Put reactants into reactant list and SV's into SVarList
      for i = 1:length(Reactants)
        if ~sum(strcmp(Reactants{i},ReactantList))
          Nrl = Nrl + 1;
          ReactantList{Nrl} = Reactants{i};
        end
        if ~( max( strcmp(Reactants{i},label) ) || strcmp(Reactants{i},'H2O') ) %FW: Judge if the reactant are labeled ions or H2O. If not, proceed.
          if ~sum(strcmp(Reactants{i},SVarList)) %FW: Judge if the reactant already exists in the variable list. If not, proceed.
            Nsv = Nsv + 1;
            SVarList{Nsv} = Reactants{i};
            % assigning Kh, Kk, and Km for this state variable 
            [v,j] = max( strcmp(SVarList{Nsv},ReactantNames) );
            KiEq = sprintf( '%s %s\r\n', KiEq, SVarList{Nsv} );
            for a = 1 : length( label )
                [ Ki( a, Nsv ) KiEqS  ] = computeKi( pK( a, j ), beta_K, beta_H2, chargeList(j), ionCharge{a}, T_tabulated_pKa, T_new, dHrK( a, j ), R );
                KiEq = [ KiEq '   pK' label{a} KiEqS ];   
            end         
            CompSVindices{CompIndex} = [CompSVindices{CompIndex} Nsv];          
          end
        end
      end
      
      %% assign proton, magnesium and potassium stoichiometry
      nI(:, kr) = zeros(3,1);
      nCO2tot(kr) = 0;
      for i = 1:length(Reactants)
        if sum(strcmp(Reactants{i},SVarList))
          [v,j] = max( strcmp(Reactants{i},SVarList) ); %FW: v is the maximal value, and j is the location, i.e., the index of the reactant.
          Qr(j,kr) = StoichArray(i); %FW: The indices, j and kr, are the locations of reactants and reactions in Qr, respectively.
        end
        % Assigning proton stoichiometry for reaction
        % the letters corresponding to the types are identified by the
        % strings in label
        for a = 1 : length( label )
            if strcmp(Reactants{i},label{a})
              nI(a, kr) = nI(a, kr) + StoichArray(i); % edited by Joep to preserve earlier values
            end
        end
        % Correcting for CO2tot in reaction
        if strcmp(Reactants{i},'CO2tot')
          nCO2tot(kr) = nCO2tot(kr) + StoichArray(i);
        end
      end
    
      %% Append compartment names
      Equations = appendCompName(Equations,comp_name,ReactantNames,kName);

      name1 = strcat('% ',Abbrv,'_',comp_name);
      FluxEquations = [FluxEquations name1 Equations]; 
  
      %% Compute dGf0
      if ~sum(strcmp(ReactionList,Abbrv))
        ReactionList{length(ReactionList)+1} = Abbrv;
%         DGeq = [];
%         for i = 1:length(Reactants)
%           if ~max(strcmp( strcat( '[', label, ']' ), Reactants{i} ))
%               ss = strcat(' +(',num2str(StoichArray(i)),')*DGfo_',Reactants{i});
%               DGeq = [DGeq ss];       
%           end
%         end
        [ DGeq DGeqS ] = IonTempCorr( T_tabulated_reactants, T_new, beta_G, beta_H, StoichArray, Reactants, ReactantNames, chargeList, protonList, dHf, dGfo, label );
        DGeqS = sprintf( 'Reaction: %s\r\n%s\r\n', Abbrv, DGeqS );
        DGeqString = [ DGeqString DGeqS ];
        DGEquations{length(DGEquations)+1} = ...
            strcat('DGro_',Abbrv,' = ',DGeq,';') ;
      end
  
      Keq = strcat('Keq_',Abbrv,'_',comp_name,' = exp(-','DGro_',Abbrv,'/RT)');
    
      %% Incorporate binding polynomials into Keq
      for i = 1:length(SVarList)
        if kr <= length( Qr( 1, : ) ) 
            if Qr(i,kr) == -1
              ss = strcat('/P(',num2str(i),')');
              Keq = [Keq ss];
            end
            if Qr(i,kr) == +1
              ss = strcat('*P(',num2str(i),')');
              Keq = [Keq ss];
            end
            if ( Qr(i,kr) > 0 ) && ( Qr(i,kr) ~= +1 )
              ss = strcat('*P(',num2str(i),')^',num2str(Qr(i,kr)));
              Keq = [Keq ss];
            end
            if ( Qr(i,kr) < 0 ) && ( Qr(i,kr) ~= -1 )
              ss = strcat('/P(',num2str(i),')^',num2str(-Qr(i,kr)));
              Keq = [Keq ss];
            end
        end
      end

    % Incorporate ion concentrations in keq
    for a = 1 : length(label)
      if nI( a, kr ) == +1
        ss = strcat('/', lower( label{a} ), '_' , comp_name );
        Keq = [Keq ss];
      end
      if nI( a, kr ) == -1
        ss = strcat('*', lower( label{a} ), '_' , comp_name );
        Keq = [Keq ss];
      end
      if ( nI( a, kr ) > 0 ) && ( nI( a, kr ) ~= +1 )
        ss = strcat('/', lower( label{a} ), '_', comp_name, '^', num2str(nI( a, kr )));
        Keq = [Keq ss];
      end
      if ( nI( a, kr ) < 0 ) && ( nI( a, kr ) ~= -1 )
        ss = strcat('*', lower( label{a} ), '_', comp_name, '^', num2str(nI( a, kr )));
        Keq = [Keq ss];
      end      
    end
        KeqEquations{kr} = strcat(Keq,';');    
    end
    
    n_svars_new = length(SVarList);
    
    %% Append compartment name to state variable names in SVarList
    for i = n_svars_begin+1:n_svars_new
      SVarList{i} = strcat(SVarList{i},'_',comp_name);     
    end    
    
    %% Construct list of clamped variables
    while strcmp(F{F_index},'clamped');
      F_index = F_index + 1;
      
      foundClamped = 0;
      % check clamped is an ion
      [v,j] = max( strcmp(label, F{F_index}) );
      if v ~= 0
          % add clamped ion index and compartment
          clamped_ions( j, CompIndex ) = 1;
          disp( sprintf( '    Clamped\t\t\t\t\t\t%s', label{ j } ) );
          foundClamped = 1;
      else
          clamped_ions( j, CompIndex ) = 0;
      end

      if foundClamped == 0
          tmpStr = strcat(F{F_index},'_',comp_name);
          % check if clamp is a reactant
          [v,j] = max( strcmp(SVarList, tmpStr ));      
          if v ~= 0
              clamped_variables = [clamped_variables j];        
              disp( sprintf( '    Clamped\t\t\t\t\t\t%s', tmpStr ) );          
          else
              disp( sprintf( '*** WARNING: Cannot find clamped variable %s', tmpStr ) );
          end
      end

      F_index = F_index + 1;
    end
end


%% Process transporters
if ~isempty(Qr) %FW: added by FW to avoid error in case of only transportation but no reactions considered in the system
    Qt = zeros(length(Qr(:,1)),1); 
end
while F_index < length(F)
  if strcmp(F{F_index},'transport')

    F_index = F_index + 1;
    comp1 = F{F_index};
    F_index = F_index + 1;
    comp2 = F{F_index};
    F_index = F_index + 1;
    disp( sprintf( '\n  Processing transport:\t\t\t%s to %s', comp1, comp2 ) );
    
    while ~sum(strcmp(keywords,F{F_index}))
      
      Abbrv = F{F_index};
      F_index = F_index + 1;
      ModelName = F{F_index};
      F_index = F_index + 1;
    
      if ~sum(strcmp(TransportAbbrvs, Abbrv)) %FW: check if the abbrv name is in the database
        noabbrv(Abbrv)
      else
        [s,Trp_i] = max(strcmp( TransportAbbrvs, Abbrv )); %FW: find the location (stored in Trp_i) of the transporter in the database
      end

      kt = kt + 1;
      [Reactants,StoichArray,TransportComps,Equations] = ...
          ReadTransportEntry(Abbrv,ModelName,TransportStoics(Trp_i),comp1,comp2);
%       QTransports{kt} = strcat(Abbrv,'_',comp1,'_to_',comp2); %FW: commented by FW
      QTransports{kt,1} = strcat(Abbrv,'_',comp1,'_to_',comp2); %FW: Modified by FW to include more information
      QTransports{kt,2} = strcat(comp1); %FW: Modified by FW to include compartment 1 (from)
      QTransports{kt,3} = strcat(comp2); %FW: Modified by FW to include compartment 2 (to)
      s = strcat(comp1,'_to_',comp2); %FW: define the name of the involved membrane
      new_membrane = 1;
      if sum( strcmp( s, Membranes ) ) %FW: check if the membrane exist in the membrane list
        [v,j] = max( strcmp( s, Membranes ) ) ; %FW: find the location of the membrane
        Qe(j,kt) = +TransportCurrents(Trp_i); %FW: find the relocated charges across the membrane
        new_membrane = 0; %FW: if it existed in the membrane list, then it is not the new membrane
      end
      s = strcat(comp2,'_to_',comp1); %FW: define the name of the involved membrane as above but with reversed oritentation
      if sum( strcmp( s, Membranes ) ) %FW: try both comp1_to_comp2 and comp2_to_comp1 to make sure either of them exist in the membrane list
        [v,j] = max( strcmp( s, Membranes ) ) ;
        Qe(j,kt) = -TransportCurrents(Trp_i); %FW: reverse the sign based on the definition
        new_membrane = 0;
      end
      % Add new membrane
      if new_membrane
        Membranes{length(Membranes)+1} = strcat(comp1,'_to_',comp2);
        Qe(length(Membranes),kt) = +TransportCurrents(Trp_i);
      end

      %% Put reactants into reactant list and SV's into SVarList
      for i = 1:length(Reactants)
        if ~sum(strcmp(Reactants{i},ReactantList))
          Nrl = Nrl + 1;
          ReactantList{Nrl} = Reactants{i};
        end
        if ~( max(strcmp(Reactants{i},label))||strcmp(Reactants{i},'H2O')||max(strcmp(Reactants{i},strcat('[',label,']'))))%edited by Joep to allow for bound protons, magnesium and so forth
          s = strcat(Reactants{i},'_',TransportComps{i});
          if ~sum(strcmp(s,SVarList))
            Nsv = Nsv + 1;
            SVarList{Nsv} = s;
            Qr(Nsv,:) = 0;
            % assigning Kh, Kk, and Km for this state variable
            [v,j] = max( strcmp(SVarList{Nsv},strcat(ReactantNames,'_',TransportComps{i})) );
            KiEq = sprintf( '%s %s\r\n', KiEq, SVarList{Nsv} );
            for a = 1 : length( label )
                [ Ki( a, Nsv ) KiEqS ] = computeKi( pK( a, j ), beta_K, beta_H2, chargeList(j), ionCharge{a}, T_tabulated_pKa, T_new, dHrK( a, j ), R );
                KiEq = [ KiEq '   pK' label{a} KiEqS ];
            end
          
            [v,j] = max(strcmp(CompList,TransportComps{i}));
            CompSVindices{j} = [CompSVindices{j} Nsv];
          
          end
        end
      end

      %% Process stoichiometry
      for i = 1:length(Reactants) %FW: go through the reactants in order
        s = strcat(Reactants{i},'_',TransportComps{i}); %FW: attach the compartment name to the reactant 
        if sum(strcmp(s,SVarList)) %FW: check if the reactant exists in the variable list
          [v,j] = max( strcmp(s,SVarList) ); %FW: locate the reactant in the variable list
          Qt(j,kt) = StoichArray(i); %FW: store the stoichiometric coeff for jth reactant in ktth transport
        end
        % Assign K M and H transport stoichiometry %FW: treat cations in a specific way for the future buffering estimation
        for a = 1 : length( label )
            if strcmp( Reactants{i}, label{a} )
                TransportStoich{a} = [ TransportStoich{a} StoichArray(i) ]; %FW: establish transport stoich for cations
                TransportComp{ a }{ length( [TransportComp{a}] ) + 1 } = TransportComps{i}; %FW: remember the location of the cation
                Transports{ a }{ length( Transports{a} ) + 1}{1} = QTransports{kt,1}; %FW: { length( Transports{a} ) + 1 } ->{ length( Transports{a} ) + 1}{1 } and {kt} -> {kt,1} by FW. remember the name of the transporter
                Transports{ a }{ length( Transports{a} )}{2} = QTransports{kt,2}; %FW: added a cell to remember the comp1
                Transports{ a }{ length( Transports{a} )}{3} = QTransports{kt,3}; %FW: added a cell remember the comp2
            end
            % Compute bound K Mg H shuttling!
            if strcmp( Reactants{i}, strcat('[',label{a},']'))
                shuttleStoich{a} = [ shuttleStoich{a} StoichArray(i) ];
                shuttleComp{ a }{ length( [shuttleComp{a}] ) + 1 } = TransportComps{i};
                shuttles{ a }{ length( shuttles{a} )+1}{1 } = QTransports{kt,1}; %FW: { length( [shuttleComp{a}] ) + 1 } ->{ length( [shuttleComp{a}] ) + 1}{1 } and {kt} -> {kt,1} by FW                              
                shuttles{ a }{ length( shuttles{a} )}{2} = QTransports{kt,2}; %FW: added to remember the comp1
                shuttles{ a }{ length( shuttles{a} )}{3} = QTransports{kt,3}; %FW: added to remember the comp2
            end            
        end
      end
      
      if ~sum(strcmp(TransportList,Abbrv)) %FW: if the transporter does not exist in the list
        ReactionList{length(TransportList)+1} = Abbrv;
        DGeq = [];
%         for i = 1:length(Reactants)
%           if ~max(strcmp( strcat( '[', label, ']' ), Reactants{i} ))
%               ss = strcat(' +(',num2str(StoichArray(i)),')*DGfo_',Reactants{i});
%               DGeq = [DGeq ss];       
%           end
%         end
        [ DGeq DGeqS ] = IonTempCorr( T_tabulated_reactants, T_new, beta_G, beta_H, StoichArray, Reactants, ReactantNames, chargeList, protonList, dHf, dGfo, label );
        DGeqS = sprintf( 'Transporter: %s\r\n%s\r\n', Abbrv, DGeqS );
        DGeqString = [ DGeqString DGeqS ];
        
        DGEquations{length(DGEquations)+1} = ...
            strcat('DGro_',Abbrv,' = ',DGeq,';') ;
      end
      
      Keq = strcat('Keq_',Abbrv,' = exp(-','DGro_',Abbrv,'/RT)');
      if TransportCurrents(Trp_i) < 0
        Keq = strcat(Keq,'* exp( +(',num2str(-TransportCurrents(Trp_i)),'*F*DPsi_',comp1,'_to_',comp2,')/RT)');
      end
      if TransportCurrents(Trp_i) > 0
        Keq = strcat(Keq,'* exp( -(',num2str(TransportCurrents(Trp_i)),'*F*DPsi_',comp1,'_to_',comp2,')/RT)');
      end

      %% Incorporate binding polynomials into Keq
      for i = 1:length(SVarList) %FW: scan the variable list to check whether it exist in the transport reaction
        if length(Qt) %FW: added by FW to prevent for scanning zero-dimenstion transport matrix
        if kt <= length( Qt( 1, : ) ) % prevent out of bound errors
          if Qt(i,kt) == -1
            ss = strcat('/P(',num2str(i),')');
            Keq = [Keq ss];
          end
          if Qt(i,kt) == +1
            ss = strcat('*P(',num2str(i),')');
            Keq = [Keq ss];
          end
          if ( Qt(i,kt) > 0 ) && ( Qt(i,kt) ~= +1 )
            ss = strcat('*P(',num2str(i),')^',num2str(Qt(i,kt)));
            Keq = [Keq ss];
          end
          if ( Qt(i,kt) < 0 ) && ( Qt(i,kt) ~= -1 )
           ss = strcat('/P(',num2str(i),')^',num2str(-Qt(i,kt)));
            Keq = [Keq ss];
          end
        end
        end %FW: added by FW to prevent for scanning zero-dimenstion transport matrix
      end
      
      %% Incorporate ion concentrations into Keq
      for i = 1:length(Reactants)
        for a = 1 : length( label )
            if strcmp( Reactants{i}, label(a) )
                if StoichArray(i) < 0
                    Keq = strcat( Keq, '*', lower( label{a} ), '_', TransportComps{i}, '^', num2str( -StoichArray(i)));
                end
                if StoichArray(i) > 0
                    Keq = strcat( Keq, '/', lower( label{a} ), '_', TransportComps{i}, '^', num2str( StoichArray(i)));
                end                
            end
        end
      end
           
      KeqEquations{kr+kt} = strcat(Keq,';'); %FW: a list of Keq including both reactions and transports
      
      name1 = strcat('% ',Abbrv,':',comp1,'_to_',comp2);
      FluxEquations = [FluxEquations name1 Equations]; %FW: a collection of all flux expressions
    end

     %% Process clamped variables
     while strcmp(F{F_index},'clamped')
      F_index = F_index + 1;        
      foundClamped = 0;
      % check clamped whether is an ion
      [v,j] = max( strcmp(label, F{F_index}) );
      if v ~= 0
          % add clamped ion index and compartment
          CompIndex1 = find( strcmp( CompList, comp1 ) );
          CompIndex2 = find( strcmp( CompList, comp2 ) );
          disp( sprintf( '    Clamped\t\t\t\t\t%s', label{ j } ) );          
          clamped_ions( j, CompIndex1 ) = 1;
          clamped_ions( j, CompIndex2 ) = 1;          
          foundClamped = 1;
      end
      
      if foundClamped == 0
          tmpStr1 = strcat(F{F_index},'_',comp1);
          tmpStr2 = strcat(F{F_index},'_',comp2);               
          [v,j] = max( strcmp(SVarList, tmpStr1 ));
          if v ~= 0
             disp( sprintf( '    Clamped\t\t\t\t\t\t%s', tmpStr1 ) );
             clamped_variables = [clamped_variables j];        
             foundClamped = 1;
          end
          [v,j] = max( strcmp(SVarList, tmpStr2 ));      
          if v ~= 0
             disp( sprintf( '    Clamped\t\t\t\t\t\t%s', tmpStr2 ) );          
              clamped_variables = [clamped_variables j];        
              foundClamped = 1;
          end
          if foundClamped == 0
              disp( sprintf( '*** WARNING: Cannot find clamped variable %s or %s', tmpStr1, tmpStr2 ) );
          end
      end
      F_index = F_index + 1;      
     end
     
    %% Construct list of species that are not hindered by specific
    %% membranes
    while strcmp(F{F_index},'permeate')
       F_index = F_index + 1;
       
       permType = 0;
       tmpStr1 = strcat(F{F_index},'_',comp1);
       [v1,pos1] = max( strcmp(SVarList, tmpStr1 ));

       tmpStr2 = strcat(F{F_index},'_',comp2);
       [v2,pos2] = max( strcmp(SVarList, tmpStr2 ));           
       
       if ( v1 ~= 0 ) || ( v2 ~= 0 )
           permType = 2;
           if v2 == 0
              % In case one of the compartments does not have this species yet
              % add this variable to the varlist
                Nsv = Nsv + 1;
                SVarList{Nsv} = tmpStr2;
                Qr(Nsv,:) = 0;
                % assigning Kh, Kk, and Km for this state variable
                [v,j] = max( strcmp(SVarList{Nsv},strcat(ReactantNames,'_',comp1)) );
                KiEq = sprintf( '%s %s\r\n', KiEq, SVarList{Nsv} );
                for a = 1 : length( label )
                    [ Ki( a, Nsv ) KiEqS ] = computeKi( pK( a, j ), beta_K, beta_H2, chargeList(j), ionCharge{a}, T_tabulated_pKa, T_new, dHrK( a, j ), R );                    
                    KiEq = [ KiEq '   pK' label{a} KiEqS ];   
                end
                pos2 = Nsv;
           end
           if v1 == 0
              % In case one of the compartments does not have this species yet
              % add this variable to the varlist
                Nsv = Nsv + 1;
                SVarList{Nsv} = tmpStr1;
                Qr(Nsv,:) = 0;
                % assigning Kh, Kk, and Km for this state variable
                [v,j] = max( strcmp(SVarList{Nsv},strcat(ReactantNames,'_',comp2)) );
                KiEq = sprintf( '%s %s\r\n', KiEq, SVarList{Nsv} );
                for a = 1 : length( label )
                    [ Ki( a, Nsv ) KiEqS ] = computeKi( pK( a, j ), beta_K, beta_H2, chargeList(j), ionCharge{a}, T_tabulated_pKa, T_new, dHrK( a, j ), R );
                    KiEq = [ KiEq '   pK' label{a} KiEqS ];   
                end
                pos1 = Nsv;
           end
       else
           % if it is not a reactant, see if it is an ion
           [v,j] = max( strcmp(label, F{F_index} ));
       end
       % still not found? then the user must have made a mistake or
       % something
       if ( v == 0 ) && ( v1 == 0 ) && ( v2 == 0 )
           disp( sprintf( '*** WARNING: Cannot find permeable species %s', F{F_index}) );
       else
           if permType == 0
               permType = 1;
           end
       end
       
       if permType ~= 0
           % permType is 1 for an ion, 2 for a reactant
           try
               [b,a] = size( permeabilities{permType} );
               a = a + 1;
           catch
               a = 1;
           end

           switch permType
               case 1
                   % store the type of ion and compartments we are
                   % permeating (indices)
                   permeabilities{1}( 1 , a ) = j;
                   pos1 = find( strcmp( CompList, comp1 ) );
                   pos2 = find( strcmp( CompList, comp2 ) );
                   permeabilities{1}( 2 , a ) = pos1; % parent compartment index
                   permeabilities{1}( 3 , a ) = pos2; % child compartment index
               case 2
                   % store the indices of the reactants involved
                   permeabilities{2}( 1 , a ) = pos1; % parent index
                   permeabilities{2}( 2 , a ) = pos2; % child index
                   permeabilities{2}( 3,  a ) = find( strcmp( CompList, comp1 ) ); % parent compartment
                   permeabilities{2}( 4,  a ) = find( strcmp( CompList, comp2 ) ); % child compartment
           end
           disp( sprintf( '    Permeable reactant\t\t\t%s', F{F_index} ) );
       end
       F_index = F_index + 1;
    end
  end
end
Ncomp = CompIndex;

%% If we didn't make any dependencies, just create some empty ones
try 
    permeabilities{1}(3,1);
catch
    permeabilities{1}(3,1) = -1;
end
try 
    permeabilities{2}(2,1);
catch
    permeabilities{2}(2,1) = -1;
end

%% Sort dependencies
%  Here we rearrange the list of dependencies in such a way that multiple
%  dependencies depend on one unique variable rather than a complex network
%  of dependencies.
%
% for example:
%  i_im depends on i_matrix
%  i_cyto depends on i_im
% will be rearranged into:
%  i_im depends on i_matrix
%  i_cyto depends on i_matrix
%
% This is done using an iterative scheme

changes = 1;
while( changes == 1 )
    
    changes = 0;

    % reactants
    for a = 1 : length( permeabilities{2}(1,:) )
        % grab a parent variable and see whether it also appears in the
        % list of child variables
        [n] = find( permeabilities{2}(2,:) == permeabilities{2}(1,a) );
        if length( n ) > 0
            % for the ones that are found, replace the parent of the child
            permeabilities{2}(1,a) = permeabilities{2}(1,n(1));
            changes = 1;
        end
    end    
    
    % ions
    for a = 1 : length( permeabilities{1}(1,:) )
        % get all the indices of the variables in the array of variables
        % other variables depend on that also appear in the list of parent variables.
        [n] = find( permeabilities{1}(3,:) == permeabilities{1}(2,a) );
        if length( n ) > 0
            % for the ones that are found, replace them in the parent position
            permeabilities{1}(2,a) = permeabilities{1}(2,n(1));
            changes = 1;
        end
    end
    
end

%% Changing 'P_{ReactantName}' to 'P(i)' in Flux Equations
FluxEquations = IndexPHMK(FluxEquations,SVarList,kName);

%% Searching for and replacing unspecified parameters in FluxEquations
for i = 1:length(FluxEquations)
  characters = char(FluxEquations{i});
  istart = []; % list of start indexes of 'unspecified's
  j = 1; 
  while j <= length(characters)-10
    if strcmp(characters(j:j+10),'unspecified')
      Npar = Npar + 1;
      istart = [istart j];
    end
    j = j+1;
  end
  % Concatenate the equation script
  if isempty(istart)
    eq = characters;
  else
    eq = characters(1:istart(1)-1);
    for j = 1:(length(istart)-1)
      ipar = ipar+1;
      ParList{length(ParList)+1} = strtok(eq, ' =' ); % added by Joep
      eq = strcat(eq,'par(',num2str(ipar),')',characters(istart(j)+11:istart(j+1)-1) ); 
    end
    ipar = ipar+1;
    ParList{length(ParList)+1} = strtok(eq, ' =' ); % added by Joep    
    eq = strcat(eq,'par(',num2str(ipar),')',characters(istart(end)+11:end));   
  end
  FluxEquations{i} = char(eq);
end

%% Construct Output File
fid = fopen(OutputFile,'w');

if fid == -1
    error( 'File could not be opened for writing...' );
end

c = '%';
cc = '%%';

fprintf(fid,'%% function [f,J%s] = dXdT(t,x,T,BX,K_BX,par)\r\n%%\r\n', strcat(', ',exportVars) );
fprintf(fid,'%%\r\n%%\r\n');
fprintf(fid,'%% Output parameters:\r\n');
fprintf(fid,'%%   f     time derivatives of the model\r\n');
fprintf(fid,'%%   J     flux\r\n');
if length( exportVars ) > 0
    fprintf(fid,'%%   ...   additional output parameters (%s)\r\n', exportVars );
end
fprintf(fid,'%%\r\n%%\r\n');
fprintf(fid,'%% Mandatory input parameters:\r\n' );
fprintf(fid,'%%   t     time\r\n' );
fprintf(fid,'%%   x     state variables at t=0\r\n' );
fprintf(fid,'%%   T     temperature in degreesCelcius\r\n' );
fprintf(fid,'%%   BX    buffer sizes\r\n' );
bufferList = '';
for a = 1 : length( CompList )
    bufferList = [ bufferList ' ' CompList{a} ];
end
fprintf(fid,'%%   K_BX  proton buffer dissociation constants (%s )\r\n', bufferList );
fprintf(fid,'%%   par   parameter vector for the free parameters\r\n' );
fprintf(fid,'%%   \r\n' );
fprintf(fid,'%%\r\n%% State Variables:\r\n' );
fprintf(fid,'%% [');
for tmp = 1 : length( SVarList )
    if tmp ~= 1
        fprintf( fid, ', ' );
    end
    fprintf( fid, '%s ', SVarList{tmp} );
end
fprintf(fid,']\r\n');
fprintf(fid,'%%\r\n%%\r\n%% Free Parameters:\r\n' );
fprintf(fid,'%% [');
for tmp = 1 : length( ParList )
    if tmp ~= 1
        fprintf( fid, ', ' ); 
    end
    fprintf( fid, '%s ', ParList{tmp} );
end
fprintf(fid,']\r\n\r\n');
fprintf(fid,'function [f,J,varargout] = dXdT(t,x,T,BX,K_BX,par)\r\n');

fprintf(fid,'%s GLOBAL VARIABLES\r\n', cc );  % added by Joep. FW: cc is used to replace %s
fprintf(fid, '%s', GlobalLines );            % added by Joep

fprintf(fid,'%s LIST OF STATE VARIABLES\r\n',cc);

for i = 1:Nsv
   % check if this reactant has infinite permeability for any membrane
  [I] = find( permeabilities{2}(2,:) == i ); %  added permeabilities. FW: judge if the ith state variable has infinite permeability property
  if length(I) > 0
      for pp = 1 : length( I )
          % if so, replace the variable with its parent variable
          fprintf(fid,'%s %s = %i %s\r\n',c,SVarList{i},permeabilities{2}(1,I(pp)),SVarList{permeabilities{2}(1,I(pp))});
      end
  else
      fprintf(fid,'%s %i %s\r\n',c,i,SVarList{i});
  end
end

%% add the ion state variables
for i = 1:Ncomp
  for a = 1 : length( label )
                      
    [I] = find( permeabilities{1}(1,:) == a );
    processedIon = 0;
    if length( I ) > 0
        for pp = 1 : length( I )
            if ( i == permeabilities{1}(2,I(pp)) )
                fprintf(fid,'%s %i %s_%s\r\n',c,Nsv+3*(i-1)+a,lower(label{a}),CompList{i});
                processedIon = 1;
            end
            if ( i == permeabilities{1}(3,I(pp)) )
                fprintf(fid,'%s %i %s_%s = %s_%s\r\n',c,Nsv+3*(i-1)+a,lower(label{a}),CompList{permeabilities{1}(2,I(pp))}, lower(label{a}), CompList{i});
                processedIon = 1;
            end
        end
    end
    if processedIon == 0;
        fprintf(fid,'%s %i %s_%s\r\n',c,Nsv+3*(i-1)+a,lower(label{a}),CompList{i});
    end
  end
end
for i = 1:length(Membranes)
  ii = (Nsv + 3*Ncomp + i);
  fprintf(fid,'%s %i DPsi_%s\r\n',c,ii,Membranes{i} );
end
fprintf(fid,'\r\n');

fprintf(fid,'%% PARTIAL VOLUME FRACTIONS\r\n' );
for i = 1:Ncomp
%   fprintf(fid,'V_%s = %g;\r\n',CompList{i},Volumes(i)); %FW:commented by FW.
  fprintf(fid,'VWater_%s = %g; %s [=] l water (l region)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 \r\n',CompList{i},VolumesWater(i),c); %FW:added by FW.
  fprintf(fid,'VRegion_%s = %g; %s [=] l region (l tissue)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 \r\n',CompList{i},VolumesRegion(i),c); %FW:added by FW.
end
fprintf(fid,'\r\n');
fprintf(fid,'%s THERMODYNAMIC DATA\r\n',cc);
fprintf(fid,'RT = 8.314*(T+273.15)/1e3; %s kJ  mol^{-1}\r\n',c);
fprintf(fid,'F = 0.096484; %s kJ mol^{-1} mV^{-1}\r\n',c);

%FW: Output state variables
fprintf(fid,'\r\n');
fprintf(fid,'%s STATE VARIABLES\r\n',cc);
fprintf(fid,'\r\n');
%FW: First output concentrations of reference species
fprintf(fid,'%s Concentrations of Reference Species\r\n',c);
for i = 1:Nsv
  [I] = find( permeabilities{2}(2,:) == i ); %  added permeabilities    
  if length(I) > 0
      fprintf(fid,'%s = x(%i); %% Permeability\r\n',SVarList{i},permeabilities{2}(1,I));
  else
      fprintf(fid,'%s = x(%i);\r\n',SVarList{i},i);
  end
end

% to compute temperature and ionic strength c0rrected free energy of
% formation
% for i = 1:Nrl
%  [v,j] = max( strcmp(ReactantList{i},ReactantNames) );
%  if ~max(strcmp( strcat( '[', label, ']' ), ReactantList{i} ))
%     dGf(i) = dGfo(j) - beta_G*chargeList(j)^2; % ionic strength corrected dGf
%     DHf = dHf(i); 
%     DHf(isnan(DHf)) = 0; % if enthalpy is not specified in the database, it is set to 0
%     DHf = DHf + beta_H*chargeList(j)^2; 
%     dGf(i) =  (1-(T_new/T_tabulated_reactants)) * DHf + (T_new/T_tabulated_reactants) * dGf(i); % temperature corrected Gibbs free energy of formation
%    fprintf(fid,'DGfo_%s = %g;\r\n',ReactantList{i},dGf(i) );
%  end
% end

%FW: Second output concentrations of ions
fprintf(fid,'%s Concentrations of H, Mg, and K\r\n',c);
for i = 1:Ncomp
    for a = 1 : length( label )
        % find all the permeabilities that involve the current ion
        [I] = find( permeabilities{1}(1,:) == a );
        
        processedIon = 0;
        % if permeabilities are found start checking
        if length( I ) > 0
            % loop over all permeabilities
            for pp = 1 : length( I )
                % if the current compartment equals the one of the parent
                % then this one is the actual parent concentration and
                % should be fetched
                if ( i == permeabilities{1}(2,I(pp)) )
                    fprintf(fid,'%s_%s = x(%i);\r\n',lower(label{a}),CompList{i},Nsv+3*(i-1)+a);
                    processedIon = 1;
                end
                % however, if it is a child parameter, then it is gonna be
                % replaced by it's parent parameter.
                if ( i == permeabilities{1}(3,I(pp)) )
                    fprintf(fid,'%s_%s = x(%i); %% Permeation\r\n',lower(label{a}), CompList{i},Nsv+3*(permeabilities{1}(2,I(pp))-1)+a );
                    processedIon = 1;
                end
            end
        end
        if processedIon == 0;
            fprintf(fid,'%s_%s = x(%i);\r\n',lower(label{a}), CompList{i},Nsv+3*(i-1)+a);
        end
    end
end
fprintf(fid,'\r\n');
%FW: Third output membrane potentials
fprintf(fid,'%s Membrane potentials\r\n',c);
for i = 1:length(Membranes)
  fprintf(fid,'DPsi_%s = x(%i);\r\n',Membranes{i},Nsv+3*Ncomp+i);
end
fprintf(fid,'\r\n');

%FW: Output binding polynomials and thermodynamic properties
%FW: First, dissociation constants
fprintf(fid,'%s DISSOCIATION CONSTANTS\r\n',cc);
for i = 1:Nsv
  fprintf( fid, '%% %s\r\n', SVarList{i} );
  for a = 1 : length( label )      
      fprintf( fid, 'K%s(%i) = %.50g;\r\n', lower(kName{a}), i, Ki(a,i) );
  end
end
fprintf(fid,'\r\n');
% computing ionic strenth and temperature corrected Gibbs free energy of formation
%FW: Second, binding polynomials
fprintf(fid,'%s BINDING POLYNOMIALS\r\n',cc);
for i = 1:Ncomp
  ii = CompSVindices{i};
  for j = 1:length(ii)
    jj = ii(j);
    P_Equation = ['P( ' num2str(jj) ' ) = 1 '];
    for a = 1 : length( label )
        P_Equation = [ P_Equation ' + ' lower( label{a} ) '_' CompList{i} '/K' lower(kName{a}) '(' num2str(jj) ')' ];
    end
    P_Equation = [ P_Equation ';\r\n' ];
    fprintf( fid, P_Equation );
  end
end
fprintf(fid,'\r\n');
%FW: Third, thermodynamic equations
fprintf(fid,'%s THERMODYNAMIC EQUATIONS\r\n',cc);
for i = 1:length(DGEquations)
  fprintf(fid,'%s\r\n',char(DGEquations{i}));
end
fprintf(fid,'\r\n');
for i = 1:length(KeqEquations)
  fprintf(fid,'%s\r\n',char(KeqEquations{i}));
end
fprintf(fid,'\r\n');

%FW: Output flux expressions
fprintf(fid,'%s FLUX EQUATIONS\r\n',cc);
for i = 1:length(FluxEquations)
  fprintf(fid,'%s\r\n',char(FluxEquations{i})); %FW: \r\n is changed into \r\n\r\n by FW. 
end
fprintf(fid,'\r\n');

%FW: Output time derivatives
fprintf(fid,'%s REACTANT TIME DERIVATIVES\r\n',cc);
[mr,nr] = size(Qr);
[mt,nt] = size(Qt);
j = 0;
funcsDone = [];
for i = 1:Ncomp
  ii = CompSVindices{i};
  for j = 1:length(ii)
    waterSpaces = [];
    jj = ii(j);
    
      [I] = find( permeabilities{2}(1,:) == jj );
      [I2] = find( permeabilities{2}(2,:) == jj );
      I = [I,I2];
      if ( length(I) > 0 )
        % grab reactant numbers involved in permeability
        % 1 always contains the parent, since that is unique
        % thanks to the iterative scheme
        func = permeabilities{2}(1,I);
        
        % find the indices of all the children parameters with the same parent parameter
        Itemp = find( permeabilities{2}(1,:) == permeabilities{2}(1,I(1)) );
        
        % grab a list of the involved water spaces
        waterSpaces = unique([permeabilities{2}(3,Itemp), permeabilities{2}(4,Itemp)]);
        
        % if the function was already created once
        foundFunc = 0;
        for pp = 1 : length( func )
            foundFunc = max( foundFunc, max( funcsDone == func(pp) ) );
        end
        if foundFunc
            fprintf(fid,'f(%i,:) = f(%i,:) + ( 0 ',func(1), func(1) );
        else
            % otherwise make it start at 0 but add it to the list
            % so that it doesn't overwrite the existing info next time
            % it runs by this function
            fprintf(fid,'f(%i,:) = ( 0 ',func(1) );
            funcsDone = [ funcsDone func ];
        end
      else
        fprintf(fid,'f(%i,:) = ( 0 ',jj); %FW: write the start of the derivative expression
      end
      
        if ~sum(jj==clamped_variables)
          for k = 1:nr
            if Qr(jj,k) > 0
              fprintf(fid,' + %g*J_%s',Qr(jj,k),QReactions{k});
            end
            if Qr(jj,k) < 0
              fprintf(fid,' - %g*J_%s',-Qr(jj,k),QReactions{k});
            end
            % Construct stoichiometry matrix
            if Qr( jj, k ) ~= 0
                StoM( jj, k ) = Qr( jj, k );
            end
          end
          for k = 1:nt
            if Qt(jj,k) > 0
%               fprintf(fid,' + %g*J_%s',Qt(jj,k),QTransports{k}); %FW: commented by FW
                if strcmp(CompList{i},QTransports{k,2}) %FW: added by FW. Judge if the state variable located in comp1 (transport comp1->comp2)
                    fprintf(fid,' + %g*J_%s/VRegion_%s*VRegion_%s',Qt(jj,k),QTransports{k,1}, QTransports{k,2}, QTransports{k,3}); %FW: revised to include region volume fractions
                else
                    fprintf(fid,' + %g*J_%s',Qt(jj,k),QTransports{k,1});
                end
            end
            if Qt(jj,k) < 0
%               fprintf(fid,' - %g*J_%s',-Qt(jj,k),QTransports{k}); %FW: commented by FW
                if strcmp(CompList{i},QTransports{k,2}) %FW: added by FW. Judge if the state variable located in comp1 (transport comp1->comp2)
                    fprintf(fid,' - %g*J_%s/VRegion_%s*VRegion_%s',-Qt(jj,k),QTransports{k,1}, QTransports{k,2}, QTransports{k,3}); %FW: revised to include region volume fractions
                else
                    fprintf(fid,' - %g*J_%s',-Qt(jj,k),QTransports{k,1});
                end
            end
            % Construct stoichiometry matrix
            if Qt( jj, k ) ~= 0
                StoM( jj, k + nr ) = Qt( jj, k );
            end
          end
          % for permeated membranes, we need to add the compartment spaces
          % accordingly
          if length( waterSpaces ) > 0
            fprintf(fid,' ) / ( 0' );
            for pp = 1 : length( waterSpaces )
%                 fprintf( fid, ' + V_%s', CompList{ waterSpaces(pp) } );%FW: commented by FW
                fprintf( fid, ' + VWater_%s', CompList{ waterSpaces(pp) } ); %FW: revised to indentify the water volume fraction
                % Construct volume matrix
                try
%                     Lm( jj, jj ) = Lm( func(1), func(1) ) + Volumes( waterSpaces(pp) );  %FW: commented by FW
                    Lm( jj, jj ) = Lm( func(1), func(1) ) + VolumesWater( waterSpaces(pp) );  %FW: revised by FW
                catch
%                     Lm( jj, jj ) = Volumes( waterSpaces(pp) ); %FW: commented by FW
                    Lm( jj, jj ) = VolumesWater( waterSpaces(pp) );  %FW: revised by FW
                end
            end
            fprintf(fid,' );' );
          else
%             fprintf(fid,' ) / V_%s; ',CompList{i}); %FW: commented by FW
            fprintf(fid,' ) / VWater_%s; ',CompList{i}); %FW: revised by FW
            % Construct volume matrix
%             Lm( jj, jj ) = Volumes(i); %FW: commented by FW
            Lm( jj, jj ) = VolumesWater(i); %FW: revised by FW
          end
        else
%             Lm( jj, jj ) = Volumes(i); %FW: commented by FW
            Lm( jj, jj ) = VolumesWater(i); %FW: revised by FW
            StoM( jj, : ) = 0;
            fprintf(fid,' ); %% [clamped] ' );
        end
        fprintf(fid,'%s %s\r\n',c,SVarList{jj});
    
  end
end
fprintf(fid,'\r\n');
fprintf(fid,'%s ION EQUATIONS\r\n',cc);
  
for i = 1:Ncomp
  fprintf(fid,'%s COMPARTMENT %s:\r\n',c,CompList{i});
  fprintf(fid,'ii = [%s]; %s Indices of SVs in compartment %s\r\n',...
      num2str(CompSVindices{i}),c,CompList{i});
  fprintf(fid,'%s PARTIAL DERIVATIVES\r\n',c);
  fprintf(fid,'pHBpK = -sum( (h_%s*x(ii)%s./Kh(ii))./(Kk(ii).*P(ii).^2) );\r\n',...
      CompList{i}, char(39));
  fprintf(fid,'pHBpM = -sum( (h_%s*x(ii)%s./Kh(ii))./(Km(ii).*P(ii).^2) );\r\n',...
      CompList{i}, char(39));
  fprintf(fid,'pHBpH = +sum( (1+m_%s./Km(ii)+k_%s./Kk(ii)).*x(ii)%s./(Kh(ii).*P(ii).^2) );\r\n',...
      CompList{i},CompList{i}, char(39));
  fprintf(fid,'pMBpH = -sum( (m_%s*x(ii)%s./Km(ii))./(Kh(ii).*P(ii).^2) );\r\n',...
      CompList{i}, char(39));
  fprintf(fid,'pMBpK = -sum( (m_%s*x(ii)%s./Km(ii))./(Kk(ii).*P(ii).^2) );\r\n',...
      CompList{i}, char(39));
  fprintf(fid,'pMBpM = +sum( (1+h_%s./Kh(ii)+k_%s./Kk(ii)).*x(ii)%s./(Km(ii).*P(ii).^2) );\r\n',...
      CompList{i},CompList{i}, char(39));
  fprintf(fid,'pKBpH = -sum( (k_%s*x(ii)%s./Kk(ii))./(Kh(ii).*P(ii).^2) );\r\n',...
      CompList{i}, char(39));
  fprintf(fid,'pKBpM = -sum( (k_%s*x(ii)%s./Kk(ii))./(Km(ii).*P(ii).^2) );\r\n',...
      CompList{i}, char(39));
  fprintf(fid,'pKBpK = +sum( (1+h_%s./Kh(ii)+m_%s./Km(ii)).*x(ii)%s./(Kk(ii).*P(ii).^2) );\r\n',...
      CompList{i},CompList{i}, char(39));
  fprintf(fid,'%s PHIs\r\n',c);
  
  
  %a refers to the type of ion
  for a = 1 : length( label ) 
      fprintf(fid,'J_%s = (0', label{a});

      % check if the ion is part of some set permeabilities
      [I] = find( permeabilities{1}(1,:) == a );
      
      waterSpaces = [];
      if length( I ) > 0
          % if so, check which permeability this ion/compartment
          % combination is involved with
          [I2] = [ find( permeabilities{1}(2,I) == i ), find( permeabilities{1}(3,I) == i ) ];
          
          if length( I2 ) > 0
            % get the parent compartment and fetch all the
            % permeabilities this is involved in
              [I3] = [ find( permeabilities{1}(2,I2(1)) == permeabilities{1}(2,:) )];
              if length( I2 ) > 0
                  % grab the water spaces
                  waterSpaces = unique( [ permeabilities{1}(2,I3), permeabilities{1}(3,I3) ] );
              end
          end
      end
      
          % protons are treated differently due to the CO2tot binding
          if a == 1
              for j = 1:length(QReactions)
                if strcmp(CompOfReaction{j},CompList{i})
                    if (nI(a,j)-2*nCO2tot(j)) >= 0 %FW: added by FW to beautify the code
                        fprintf(fid,' + %g*J_%s',nI(a,j)-2*nCO2tot(j),QReactions{j});
                    else
                        fprintf(fid,' - %g*J_%s',-nI(a,j)+2*nCO2tot(j),QReactions{j});
                    end
                end
              end
          end

          for j = 1:length(Transports{a})
            if strcmp( TransportComp{a}{j}, CompList{i} )
                if TransportStoich{a}(j) >= 0 %FW: added by FW to beautify the code
                    if strcmp(CompList{i},Transports{a}{j}{2}) %FW: added by FW. Judge if the state variable located in comp1 (transport comp1->comp2)
                        fprintf(fid,' + %g*J_%s/VRegion_%s*VRegion_%s',TransportStoich{a}(j),Transports{a}{j}{1}, Transports{a}{j}{2}, Transports{a}{j}{3}); 
                    else
                        fprintf(fid,' + %g*J_%s',TransportStoich{a}(j),Transports{a}{j}{1});
                    end
                else
                    if strcmp(CompList{i},Transports{a}{j}{2}) %FW: added by FW. Judge if the state variable located in comp1 (transport comp1->comp2)
                        fprintf(fid,' - %g*J_%s/VRegion_%s*VRegion_%s',-TransportStoich{a}(j),Transports{a}{j}{1}, Transports{a}{j}{2}, Transports{a}{j}{3}); 
                    else
                        fprintf(fid,' - %g*J_%s',-TransportStoich{a}(j),Transports{a}{j}{1});
                    end
                end
            end
          end

          % move protons, potassium and magnesium that are bound to 
          % translocated species
          for j = 1:length(shuttles{a})
            if strcmp( shuttleComp{a}{j}, CompList{i} )
                if shuttleStoich{a}(j) >= 0 %FW: added by FW to beautify the code
                    fprintf(fid,' + %g*J_%s/VRegion_%s*VRegion_%s',shuttleStoich{a}(j),shuttles{a}{j}{1},shuttles{a}{j}{2},shuttles{a}{j}{3}); 
                else
                    fprintf(fid,' - %g*J_%s/VRegion_%s*VRegion_%s',-shuttleStoich{a}(j),shuttles{a}{j}{1},shuttles{a}{j}{2},shuttles{a}{j}{3});
                end
            end
          end
      
      % if we need to consider multiple water spaces, do so!
      if length( waterSpaces ) > 0
        fprintf(fid,' ) / ( 0' );
        for pp = 1 : length( waterSpaces )
%             fprintf( fid, ' + V_%s', CompList{ waterSpaces(pp) } ); %FW: commented by FW
             fprintf( fid, ' + VWater_%s', CompList{ waterSpaces(pp) } ); %FW: added by FW
        end
        fprintf(fid,' );\r\n' );
      else
%         fprintf(fid,') / V_%s;\r\n',CompList{i}); %FW: commented by FW
        fprintf(fid,') / VWater_%s;\r\n',CompList{i}); %FW: added by FW
      end
  end
  
  fprintf(fid,'Phi_H = J_H - sum( h_%s*f(ii)%s./(Kh(ii).*P(ii)) );\r\n',CompList{i},char(39));
  fprintf(fid,'Phi_M = J_M - sum( m_%s*f(ii)%s./(Km(ii).*P(ii)) );\r\n',CompList{i},char(39));
  fprintf(fid,'Phi_K = J_K - sum( k_%s*f(ii)%s./(Kk(ii).*P(ii)) );\r\n',CompList{i},char(39));
  fprintf(fid,'%s ALPHAs\r\n',c);
  fprintf(fid,'aH = 1 + pHBpH;\r\n');
  fprintf(fid,'aM = 1 + pMBpM;\r\n');
  fprintf(fid,'aK = 1 + pKBpK;\r\n');
  fprintf(fid,'%s ADDITIONAL BUFFER for [H+]\r\n',c);
  fprintf(fid,'aH = 1 + pHBpH + BX(%d)/K_BX(%d)/(1+h_%s/K_BX(%d))^2; %s M\r\n',i,i,CompList{i},i,c);
  fprintf(fid,'%s DENOMINATOR\r\n',c);
  fprintf(fid,'D = aH*pKBpM*pMBpK + aK*pHBpM*pMBpH + aM*pHBpK*pKBpH - ...\r\n');
  fprintf(fid,'    aM*aK*aH - pHBpK*pKBpM*pMBpH - pHBpM*pMBpK*pKBpH;\r\n');
  fprintf(fid,'%s DERIVATIVES for H,Mg,K\r\n',c);
  
  for a = 1 : length( label )

      % a = ion
      % i = compartment
      % in the list of permeabilities, the first ion in the compartment
      % list is the 'parent' concentration. This is the state variable that will
      % be used for computing things.
     
      parentCompartment = i;
      fluxNo = Nsv+3*(i-1)+a;
      pre = '';
      
      % check if the ion is part of some set permeability
      [I] = find( permeabilities{1}(1,:) == a );
      if length( I ) > 0
          for pp = 1 : length( I )
              % check if this specific ion/compartment combination is part of a
              % set permeability
              if ( i == permeabilities{1}(2,I(pp)) )
                  fluxNo = Nsv+3*(i-1)+a;                 
              end
              if ( i == permeabilities{1}(3,I(pp)) )
                  parentCompartment = permeabilities{1}(2,I(pp));
                  fluxNo = Nsv+3*(permeabilities{1}(2,I(pp))-1)+a;
              end             
          end
      end     

      % keep track of fluxes that were done so they aren't accidentally
      % removed  
      if length(find( fluxesDone == fluxNo )) < 1 
          fluxesDone = [ fluxesDone fluxNo ];
      else
        pre = sprintf( 'f(%i,:) + ', fluxNo );
      end
      
      % check if the ion is clamped
      try
          clamped = clamped_ions(a,parentCompartment); % used to be j
      catch
          clamped = 0;
      end
         
      if clamped == 0
          % which ion are we dealing with here
          switch a
              case 1
                  % %s was added to enable preservation of the original
                  % flux expression
                  fprintf(fid,'f(%i,:) = %s ( (pKBpM*pMBpK - aM*aK)*Phi_H + ...\r\n', fluxNo, pre);
                  fprintf(fid,'            (aK*pHBpM - pHBpK*pKBpM)*Phi_M + ...\r\n');
                  fprintf(fid,'            (aM*pHBpK - pHBpM*pMBpK)*Phi_K ) / D;\r\n');
              case 2
                  fprintf(fid,'f(%i,:) = %s ( (aK*pMBpH - pKBpH*pMBpK)*Phi_H + ...\r\n', fluxNo, pre);
                  fprintf(fid,'            (pKBpH*pHBpK - aH*aK)*Phi_M + ...\r\n');
                  fprintf(fid,'            (aH*pMBpK - pHBpK*pMBpH)*Phi_K ) / D;\r\n');
              case 3
                  fprintf(fid,'f(%i,:) = %s ( (aM*pKBpH - pKBpM*pMBpH)*Phi_H + ...\r\n', fluxNo, pre);
                  fprintf(fid,'            (aH*pKBpM - pKBpH*pHBpM)*Phi_M + ...\r\n');
                  fprintf(fid,'            (pMBpH*pHBpM - aH*aM)*Phi_K ) / D;\r\n');
          end
      else
          fprintf(fid,'f(%i,:) = %s 0;\r\n',fluxNo, pre );
      end
  end
end
fprintf(fid,'\r\n');
fprintf(fid,'%s ELECTROPHYS EQUATIONS\r\n',cc);
[m,n] = size(Qe);
for i = 1:m
  fprintf(fid,'C_%s = par(%i);\r\n',Membranes{i},(i+Npar));
  ParList{length(ParList)+1} = [ 'C_', Membranes{i} ]; % added by Joep
  ii = Nsv + 3*Ncomp + i;
  fprintf(fid,'f(%i) = ( 0',ii );
  for j = 1:n
    if Qe(i,j) < 0
       fprintf(fid,' - %g*J_%s ',-Qe(i,j),QTransports{j,1} ); %FW: QTransports{j} -> QTransports{j,1}
     end
     if Qe(i,j) > 0
       fprintf(fid,' + %g*J_%s ',+Qe(i,j),QTransports{j,1} ); %FW: QTransports{j} -> QTransports{j,1}
     end
  end
  fprintf(fid,') / C_%s;\r\n',Membranes{i});
end

fprintf(fid,'%s FLUX VECTOR:\r\n',cc);
fprintf(fid,'J = [');
for i = 1:length(QReactions)
  fprintf(fid,' J_%s',QReactions{i}); 
end
for i = 1:size(QTransports,1) % length(QTransports) -> size(QTransports,1)
  fprintf(fid,' J_%s',QTransports{i,1}); %FW: QTransports{j} -> QTransports{j,1}
end
fprintf(fid,'];\r\n');

% add additional export parameters
fprintf(fid,'%s',exportVars2);

fid = fclose(fid);

ionStartPos = Nsv;

% Adding [H], [Mg], and [K] to SVarList
for i = 1:Ncomp
    for a = 1 : length( label )
      SVarList{Nsv+3*(i-1)+a} = strcat(label{a},'_',CompList{i});
    end
end

%% Adding Psi's to the SVarList
Nsv = Nsv + 3*Ncomp;
for i = 1:length(Membranes)
   Nsv = Nsv + 1;
   SVarList{Nsv} = strcat('DPsi_',Membranes{i});
end

%% Remove redundant parameters (that were made redundant by permeabilities)
%    -- Future work --
% reactions
% removal = permeabilities{ 2 }(2, :);
% ions
% removal = [removal Nsv + 3*(permeabilities{ 1 }(3, :)-1)+permeabilities{1}(1,:)];
% SVarList( removal ) = [];

%% Create modelInfo structure for maintainable user input

modelInfo.SVarID = struct;
modelInfo.ParID = struct;
modelInfo.FluxID = struct;
for a = 1 : length( SVarList )
    % make sure the references for the permeated variables also point to
    % the correct variables
    [I] = find( permeabilities{2}(2,:) == a );
    % if this is a permeated variable, make the SVarID point to it's parent
    % variable rather than the child variable (which will not be used)
    if length(I) > 0
        modelInfo.SVarID =  setfield( modelInfo.SVarID, SVarList{a}, permeabilities{2}(1,I(1)) );
    else
        modelInfo.SVarID =  setfield( modelInfo.SVarID, SVarList{a}, a );
    end
end
for i = 1:Ncomp
    for a = 1 : length( label )
        % find all the ions of this type
        [I] = find( permeabilities{1}(1,:) == a );
        if length( I ) > 0
            % find the ones that are actually in the compartment we are
            % currently setting the field on and considered 'child'
            % variable
            [I2] = find( permeabilities{1}(3,I) == i );
            if length( I2 ) > 0
                % instead of using their own variable position make the
                % structure point to their parent variable.
                modelInfo.SVarID = setfield( modelInfo.SVarID, SVarList{ionStartPos+3*(i-1)+a}, ionStartPos+3*(permeabilities{1}(2,I(I2(1)))-1)+permeabilities{1}(1,I(I2(1))));
            end
        end
    end
end

for a = 1 : length( ParList )
    modelInfo.ParID =   setfield( modelInfo.ParID, ParList{a}, a );
end
for a = 1 : length( QReactions )      
    modelInfo.FluxID =  setfield( modelInfo.FluxID, QReactions{a}, a );
end
for a = 1 : size(QTransports,1) %FW: length( QTransports ) -> size(QTtransports,1)    
    modelInfo.FluxID =  setfield( modelInfo.FluxID, QTransports{a,1}, a + length( QReactions ) ); %FW: QTransports{a} -> QTransports{a,1} 
end
modelInfo.SVarList = SVarList;
modelInfo.matrices.stoichMatrix = StoM;
modelInfo.matrices.volMatrix = Lm;

disp( sprintf( '\n  Computing conservation matrix' ));

vols = diag( Lm );
for a = 1 : length( vols )
    StoM(a,:) = (1/vols(a)) .* StoM( a,: );
end

try
    [ conMatrix varList ]= conservationMatrix( StoM, [1 : ionStartPos] );
catch
    disp( sprintf( ...
            'WARNING: Cannot compute conservation matrix!' ) );
end

modelInfo.matrices.conservationVars = varList;
modelInfo.matrices.conservationMatrix = conMatrix;

%modelInfo.matrices.conservationMatrix = null( ( inv( Lm ) * StoM ).' ).';
%[nx, ny] = size( StoM );
%if min( [ nx, ny ] ) == 1
%    modelInfo.matrices.conservationMatrix = modelInfo.matrices.conservationMatrix( 1, : );
%end

fname = strcat(OutputFile(1:end-2),'.mat');
lname = strcat(OutputFile(1:end-2),'.log');
save(fname, 'modelInfo');
fid = fopen( lname, 'w' );
fprintf( fid, '%s', BISENlogo(2) );
fprintf( fid, '----------------\r\nGIBBS ENERGIES\r\n----------------\r\n\r\n%s', DGeqString );
fprintf( fid, '-----------------\r\nPKA CORRECTIONS\r\n-----------------\r\n\r\n%s',KiEq );
fid = fclose( fid );
disp(sprintf('\n  Model files created:\t\t\t%s, %s, %s', OutputFile, fname, lname ) );
disp(sprintf('    Compartments:\t\t\t\t%d', length( CompList ) ) );
disp(sprintf('    State variables:\t\t\t%d', length( SVarList ) ) );
disp(sprintf('    Parameters:\t\t\t\t\t%d', length( ParList ) ) );
disp(sprintf('    Reaction fluxes:\t\t\t%d', length( QReactions ) ) );
if length( CompList ) > 1
    disp(sprintf('    Transport fluxes:\t\t\t%d',size(QTransports,1) ) ); %FW: length( QTransports ) -> size(QTransports,1)
else
    disp(sprintf('    Transport fluxes:\t\t\tNot applicable' ) );
end
disp(sprintf('\r\n\r\n***  Model constructed successfully.\r\n\r\n'));
