% Correct for temperature and ionic strength
%
% Mandatory inputs:
% input:
% T_old             - Tabulated temperature
% T_new             - New temperature
% beta_G            - Constant for specific (T,I)
% beta H            - Constant for specific (T,I)
%                     (use getIonicStrengthCorrectionFactors)
% StoichArray       - Stoichiometry for this reaction
% Reactants         - List of reactants involved in this reaction
% ReactantNames     - Database of reactants 
% zList             - Database of species charges
% dHfList           - Database of enthalpies
% dGfoList          - Database of Gibbs energies

function varargout = IonTempCorr( ...
    T_old, T_new, beta_G, beta_H, StoichArray, Reactants, ReactantNames, ...
    zList, hList, dHfList, dGfoList, label )
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.

noEnthalpies = 0;

% Set up some lines for the info file
DGString = '  0';
DHString = '  0';
DfGString = '  0';
DfHString = '  0';
ZString = '  0'; 

drG = 0;
dfG = 0; % to get temperature and ionic strength corrected dfG
drH = 0;
dfH = 0; % to get temperature and ionic strength corrected dfH
Q = 0;
Qf = 0; % initiating for free energy

for i = 1:length(Reactants)
    
    if ~max(strcmp( [ strcat( '[', label, ']' ) ] , Reactants{i} ))
        [v,j] = max( strcmp( Reactants{i}, ReactantNames ) );
        if v == 0
            error( sprintf( ...
            'Cannot find abbreviation %s in reactant list!', Reactants{i} ) );
            return;
        end

        % assemble dG of reaction
        drG = drG + StoichArray(i) * ( dGfoList( j ) ); %-beta_G*(zList(j)^2)
        dfG = ( dGfoList( j ) ); % free energy of reactants
        DGString = [ DGString sprintf( ...
            ' + (%d)dG_%s[%.3f]', StoichArray(i), Reactants{i}, dGfoList(j) ) ];
        DfGString = [ DfGString sprintf( 'dfG_%s', Reactants{i} ) ]; % collecting free energy of reactants
        try
            % assemble dH of reaction
            drH = drH + StoichArray(i) * dHfList( j );
            dfH = StoichArray(i) * dHfList( j ); % enthalpy of reactants
            DfHString = [ DHString sprintf( 'dfH_%s', Reactants{i} ) ]; 
            
            if isnan( drH )
                noEnthalpies = 1;
            end
        catch
            % enthalpy missing, abort correction
            noEnthalpies = 1;
        end
       
        % assemble quadratic charge change
        Q = Q + StoichArray(i) * zList(j)^2;% - StoichArray(i) * hList(j);
        Qf = StoichArray(i) * zList(j)^2;% - StoichArray(i) * hList(j);
        ZString = [ ZString sprintf( ...
            ' + (%d)z_%s[%f]', StoichArray(i), Reactants{i}, dGfoList(j) ) ];
        if isnan( zList(j) )
            error( sprintf( ...
                'Reactant %s does not have a charge associated with it!', Reactants{i} ) );
            return;
        end
    end
end


% compute Gibbs energy at correct ionic strength
drG   = drG - beta_G * Q;
dfG   = dfG - beta_G * Qf;
CString = sprintf( ...
    '  Ionic strength correction: DrG[%f] - beta_G[%f] * Q[%f] = %f\r\n', ...
    drG + beta_G*Q, beta_G, Q, drG );
CfString = sprintf( ...
    '  Ionic strength correction: DfG[%f] - beta_G[%f] * Qf[%f] = %f\r\n', ...
    dfG + beta_G*Qf, beta_G, Qf, dfG ); % for reactants
 
if ( noEnthalpies == 0 )
    % compute enthalpy at correct ionic strength
    drH   = drH + beta_H * Q;
    CString = [ CString sprintf( ...
        '  Ionic strength correction: DrH[%f] + beta_H[%f] * Q[%f] = %f\r\n', ...
        drH - beta_H*Q, beta_H, Q, drH ) ];
    
    dfH   = dfH + beta_H * Qf;
    CfString = [ CfString sprintf( ...
        '  Ionic strength correction: DfH[%f] + beta_H[%f] * Qf[%f] = %f\r\n', ...
        dfH - beta_H*Qf, beta_H, Qf, dfH ) ];
    % correct Gibbs energy for temperature
    drG   = (1-(T_new/T_old)) * drH + (T_new/T_old) * drG;
    CfString = [ CfString sprintf( ...
        '  Temp correction: drG = (1-Tn[%.2f]/To[%.2f]) * drH[%.4f] + (Tn[%.2f]/To[%.2f]) * drG = %f\r\n', ...
        T_new, T_old, drH, T_new, T_old, drG ) ];
    
    dfG   = (1-(T_new/T_old)) * dfH + (T_new/T_old) * dfG;
    CString = [ CString sprintf( ...
        '  Temp correction: dfG = (1-Tn[%.2f]/To[%.2f]) * dfH[%.4f] + (Tn[%.2f]/To[%.2f]) * dfG = %f\r\n', ...
        T_new, T_old, dfH, T_new, T_old, dfG ) ];
else
    CString = [ CString sprintf( ...
        '  No temperature correction\r\n' ) ];
end

DGeq = num2str( drG );
DfG = num2str( dfG );
DGeqString = sprintf( '%s\r\n%s\r\n%s', DGString, DHString, CString );
DfGString = sprintf( '%s\r\n%s\r\n%s', DfGString, DfHString, CString );

varargout = { DGeq, DGeqString, DfGString };