% This function computes the equilibrium constant for the first
% ion binding
%
% Mandatory input
%    pKa_in     pKa out of database at specified ionic strength and 
%    beta_K     factor from getIonicStrengthCorrectionFactors
%    beta_H     ""
%    charge     charge of the species without ion binding (from database)
%    ionCharge  charge of the ion
%    T_old      old temperature
%    T_new      new temperature
%    drH        enthalpy for ion binding reaction at same 
%               ionic strength as pKa.
function [ Ki KiEq ] = computeKi( pKa_in, beta_K, beta_H2, charge, ...
                                ionCharge, T_old, T_new, drH, R )
% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.
                            
    if ~isnan( pKa_in )
        % Calculate charge factor
        z = ( ionCharge^2 + charge^2 ) - ( charge + ionCharge )^2;
    
        % Ionic strength correction for pka
        pKa = pKa_in + beta_K * z;
        KiEq = sprintf( ...
        '\r\n     Ionic strength correction: pKa_in[%.3f] + beta_K[%.3f] * z[%.3f] = %.3f\r\n', ...
                    pKa_in, beta_K, z, pKa );
    
        % if we have a known enthalpy
        if ~isnan( drH )
    
            % calculate reaction enthalpy ionic strength dependence assuming only
            % first order binding
            drH = drH + beta_H2 * z;
            KiEq = sprintf( ...
                '%s     Ionic strength correction: dHr[%.3f] + beta_H2[%.3f] * z[%.3f] = %.3f\r\n', ...
                KiEq, drH-beta_H2*z, beta_H2, z, drH );

            pKa = pKa + ( 1/T_new - 1/T_old ) * drH/(2.3026*R);
            KiEq = sprintf( ...
                '%s     Temperature correction: pKa + (1/T_new[%.3f]-1/T_old[%.3f]) * drH[%.3f]/2.3026*R = %.3f\r\n', ...
                KiEq, T_new, T_old, drH, pKa );
        else
            sprintf( '%s     No temperature correction\r\n', KiEq );
        end
    
        % Compute equilibrium constant
        Ki = 10^( - pKa );
        KiEq = sprintf( '%s\r\n     pK = %.3f\r\n', KiEq, Ki );        
    else
        Ki = inf;
        KiEq = sprintf( '\r\n     pK = inf (No dissociation)\r\n' );
    end
