% This is the main script to execute the BISEN version of Bazil et
% al., 2016 OXPHOS model (Bazil JN, Beard DA, Vinnakota KC. 2016. Catalytic Coupling of Oxidative Phosphorylation, ATP Demand, and Reactive Oxygen Species Generation. Biophys J. ;110(4):962-71.)

% Copyright (C) 2016 Beard Lab, University of Michigan.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the University of Michigan. For details
% please see User License Agreement.
 
clear all
clear cache
clc

tic;

%% loading Vinnakota et al experimental data 
load data
%% Setting paths
path(path,'..\Warnings');
path(path,'..\BiochemicalReactions');
path(path,'..\Transporters');
path(path,'..\Databases');
path(path,'..\BuilderFiles');
path(path,'..\Examples');

%% Building model:
modelInfo = BuildDXDT('mod_DSK_JB_OXPHOS.bsl','dXdT_DSK_JB_OXPHOS.m');
save dXdT_DSK_JB_OXPHOS.mat

%% Set the desired temperature
T = 37;

%% Set proton cytoplasm sizes
BX(1) = 0.02;       % matrix
BX(2) = 100000;     % cytoplasm
BX(3) = 100000;     % intermembrane space

%% Proton cytoplasm binding constant(s)
K_BX(1) = 1e-7;
K_BX(2) = 10^(-7.2);
K_BX(3) = 10^(-7.2);

%% incubation time
t_ib = 60;

%% Setting physical parameters for computing the graphs
W_m = 0.664*1.09;   % mitochondrial water space (ml water per ml mito) [VB2002]
W_x = 0.9*W_m;      % Matrix water space, (l mito water) (l mito)^{-1}
W_i = 0.1*W_m;      % IM water space, (l IM water) (l mito)^{-1} 
W_c = 320;           % buffer, (l buffer water) (l mito)^{-1}
rho_m = 3.6697e-6;  % (l mito) (mg protein)^{-1}

%% Load the parameters and initial conditions for in vitro simulations
% x0 = TCA_x0_vitro( modelInfo );
% params = TCA_params( modelInfo );
x0=[];params=[];

%% defining total pool concentrations

Ntot = 2.97e-3; % ANDH
Qtot = 20e-3; % coenzyme Q
Atot = 10e-3; % ADP
Ctot = 2e-4; % cytochrome C

%% defining initial conditions
x0 = [];
% MATRIX
x0 = setParameter( x0, modelInfo.SVarID, 'NAD_matrix' , Ntot - 1e-12 ); % NAD, matrix 
x0 = setParameter( x0, modelInfo.SVarID, 'NADH_matrix', 1e-12 ); % NADH, matrix
x0 = setParameter( x0, modelInfo.SVarID, 'ADP_matrix', Atot - 1e-12); % ADP, matrix
x0 = setParameter( x0, modelInfo.SVarID, 'ATP_matrix', 1e-12 ); % ATP, matrix
x0 = setParameter( x0, modelInfo.SVarID, 'Pi_matrix', 2.9916e-4 ); % Pi, matrix
x0 = setParameter( x0, modelInfo.SVarID, 'coQ_matrix', Qtot - 1e-12 ); % coQ
x0 = setParameter( x0, modelInfo.SVarID, 'coQH2_matrix', 1e-12 ); % coQH2
x0 = setParameter( x0, modelInfo.SVarID, 'H2O2aq_matrix', 1e-12 ); % mito H2O2
x0 = setParameter( x0, modelInfo.SVarID, 'SOaq_matrix', 1e-12 ); % mito SO
x0 = setParameter( x0, modelInfo.SVarID, 'O2aq_matrix', 200e-6 ); % mito O2
x0 = setParameter( x0, modelInfo.SVarID, 'M_matrix', 7e-4 ); % Mg, matrix
x0 = setParameter( x0, modelInfo.SVarID, 'H_matrix', 10^-7.2372 ); % H, matrix
x0 = setParameter( x0, modelInfo.SVarID, 'K_matrix', 0.06); % K, matrix
% CYTOPLASM
x0 = setParameter( x0, modelInfo.SVarID, 'ATP_cytoplasm', 5e-3 ); % ATP, cytoplasm (to simulate Vinnakota et al, 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'ADP_cytoplasm', 1e-9 ); % ADP, cytoplasm 
x0 = setParameter( x0, modelInfo.SVarID, 'Pi_cytoplasm', 1e-3 ); % Pi, cytoplasm (to simulate Vinnakota et al, 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'H_cytoplasm', 10^(-7.2) ); % H, cytoplasm (to simulate Vinnakota et al, 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'M_cytoplasm', 1e-3 ); % Mg, cytoplasm (to simulate Vinnakota et al, 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'K_cytoplasm', 130e-3 ); % K, cytoplasm (Bazil et al., 2015)
% IM SPACE
x0 = setParameter( x0, modelInfo.SVarID, 'cytocox_im', Ctot - 1e-12); % cytoC (ox), im (Bazil et al., 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'cytocred_im', 1e-12 ); % cytoC (red), im (Bazil et al., 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'ATP_im', 5e-3 ); % ATP, cytoplasm (to simulate Vinnakota et al, 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'ADP_im', 1e-9 ); % ADP, cytoplasm 
x0 = setParameter( x0, modelInfo.SVarID, 'Pi_im', 1e-3 ); % Pi, cytoplasm (to simulate Vinnakota et al, 2015)
x0 = setParameter( x0, modelInfo.SVarID, 'H_im', 10^(-7.2) ); % H, im
x0 = setParameter( x0, modelInfo.SVarID, 'M_im', 1e-3 ); % Mg, im (from BISEN)
x0 = setParameter( x0, modelInfo.SVarID, 'K_im', 130e-3 ); % K, im (from BISEN)
x0 = setParameter( x0, modelInfo.SVarID, 'DPsi_im_to_matrix', -14.087 ); % membrane potential, IM to matrix
x0 = setParameter( x0, modelInfo.SVarID, 'DPsi_cytoplasm_to_im', 0 ); % membrane potential, cytoplasm to IM
x00 = x0;

%% Adjusting parameters while updating models
params = [];
params = setParameter( params, modelInfo.ParID, 'x_DH', 1.1273e-1 );    % dehydrogenase
params = setParameter( params, modelInfo.ParID, 'k1_F1F0', 812 );    % F1F0
params = setParameter( params, modelInfo.ParID, 'ETC1Activity', (1.66953e-4) );    % ETC1Activity
params = setParameter( params, modelInfo.ParID, 'ETC3_activity', 0.00158489319246111 );    % ETC3Activity
params = setParameter( params, modelInfo.ParID, 'ETC4_activity', (8.91e-2) );    % ETC4Activity
params = setParameter( params, modelInfo.ParID, 'x_HLE', 1.78e3 );    % proton leak
params = setParameter( params, modelInfo.ParID, 'x_PIH', 3.34e7 );    % PiH
params = setParameter( params, modelInfo.ParID, 'x_ANT', 0.14125 );    % ANT
params = setParameter( params, modelInfo.ParID, 'x_ATPase', 0 );    % ATPase
params = setParameter( params, modelInfo.ParID, 'x_SDH', 0.25 );    % SDH
params = setParameter( params, modelInfo.ParID, 'x_KPERM', 100 );    % KPERM
params = setParameter( params, modelInfo.ParID, 'x_MPERM', 100 );    % MPERM
params = setParameter( params, modelInfo.ParID, 'x_HPERM', 1e9 );    % HPERM
params = setParameter( params, modelInfo.ParID, 'x_ATPPERM', 1000 );    % ATPPERM
params = setParameter( params, modelInfo.ParID, 'x_ADPPERM', 5000 );    % ADPPERM
params = setParameter( params, modelInfo.ParID, 'x_PIPERM', 1000 );    % PIPERM
params = setParameter( params, modelInfo.ParID, 'C_im_to_matrix', 6.7568e-06 );    % C, im to matrix
params = setParameter( params, modelInfo.ParID, 'C_cytoplasm_to_im', inf );    % C, im to matrix
params = setParameter( params, modelInfo.ParID, 'k1_KH', 4760000 );    % C, im to matrix

%% Make sure all the variables except the membrane potentials cannot become negative
varlist = [ 1 : length( modelInfo.SVarList ) ];
varlist( [ modelInfo.SVarID.DPsi_im_to_matrix,  modelInfo.SVarID.DPsi_cytoplasm_to_im ] ) = [];
% varlist( [ modelInfo.SVarID.DPsi_im_to_matrix ] ) = [];
options = [];
options = odeset('NonNegative', varlist);

%% baseline values from Jason
Apyrase = logspace(-3,0,41)*1e-6/1e-3/60; % umol/min

%% 1 mM Pi
x10 = x0;
x10 = setParameter( x0, modelInfo.SVarID, 'O2aq_matrix', 200e-6 ); 
x10 = setParameter( x0, modelInfo.SVarID, 'Pi_cytoplasm', 1e-3 ); 
params = setParameter( params, modelInfo.ParID, 'x_ATPase', 0 );    % Apyrase rate
[t_ic,x_ic] = ode15s(@dXdT_DSK_JB_OXPHOS, [0 60], x10, options, T, BX, K_BX, params );
x1 = x_ic(end,:);

for i = 1:length(t_ic)
    [f1, J1] = dXdT_DSK_JB_OXPHOS(t_ic(i), x_ic(i,:)', T, BX, K_BX, params);
    f_ic(i,:) = f1;
    J_ic(i,:) = J1;
end

for j = 1:numel(Apyrase)
    params = setParameter( params, modelInfo.ParID, 'x_ATPase', Apyrase(j) );    % ATPase
    [t{1}{j},x{1}{j}] = ode15s(@dXdT_DSK_JB_OXPHOS, [0 180], x1, options, T, BX, K_BX, params );
    for k = 1:length(t{1}{j})
        [f{1}{j}(k,:), J{1}{j}(k,:)] = dXdT_DSK_JB_OXPHOS(t{1}{j}(k), x{1}{j}(k,:)', T, BX, K_BX, params );
    end
end

%% 5 mM Pi
x20 = x0;
x20 = setParameter( x0, modelInfo.SVarID, 'Pi_cytoplasm', 5e-3 ); 
params = setParameter( params, modelInfo.ParID, 'x_ATPase', 0 );    % Apyrase rate
[t_ic2,x_ic2] = ode15s(@dXdT_DSK_JB_OXPHOS, [0 60], x20, options, T, BX, K_BX, params );
x2 = x_ic2(end,:);

for j = 1:numel(Apyrase)
    params = setParameter( params, modelInfo.ParID, 'x_ATPase', Apyrase(j) );    % ATPase
    [t{2}{j},x{2}{j}] = ode15s(@dXdT_DSK_JB_OXPHOS, [0 180], x2, options, T, BX, K_BX, params );
    for k = 1:length(t{2}{j})
        [f{2}{j}(k,:), J{2}{j}(k,:)] = dXdT_DSK_JB_OXPHOS(t{2}{j}(k), x{2}{j}(k,:)', T, BX, K_BX, params );
    end
end

%% outputs for plots

O2conv = 3.6697e-06*60*(0.06/0.337)/2*1e9; % converts mol O/s/l mito to nmol O2/min/U CS
for i=1:2
    for j=1:numel(Apyrase)
    JO2(i,j) = J{i}{j}(end, 7)*O2conv ; % nmol O2/min/U CS
    JDH(i,j) = J{i}{j}(end, 1); % mol/lmito/s
    JANT(i,j) = J{i}{j}(end, 10); % mol/lmito/s
    JF1F0(i,j) = J{i}{j}(end, 4); % mol/lmito/s    
    dPsi(i,j) = x{i}{j}(end,28); % M
    NADH(i,j) = x{i}{j}(end,2)/Ntot; % M
    UQH2(i,j) = x{i}{j}(end,7)/Qtot; % M
    c2(i,j) = x{i}{j}(end,14)/Ctot; % M
    ATP(i,j) = x{i}{j}(end,8)*1e3; % mM
    ADP(i,j) = x{i}{j}(end,9)*1e3; % mM
    ATPx(i,j) = x{i}{j}(end,4)/Atot; % M
    ADPx(i,j) = x{i}{j}(end,3)/Atot; % M
    Pix(i,j) = x{i}{j}(end,5); % M
    pHx(i,j) = -log10(x{i}{j}(end,19)); % M
    pHc(i,j) = -log10(x{i}{j}(end,22)); % M
    end
end
    
%% FOR PLOTS
compar_JNB_BISEN